@@ -2,12 +2,12 @@ package convert
 
 import (
 	"encoding/base64"
-	"net/http"
 	"strings"
 	"time"
 
 	"github.com/metacubex/mihomo/common/utils"
 
+	"github.com/metacubex/http"
 	"github.com/metacubex/randv2"
 	"github.com/metacubex/sing-shadowsocks/shadowimpl"
 )
