@@ -1,6 +1,7 @@
 package dns
 
 import (
+	"errors"
 	"net/netip"
 
 	"github.com/metacubex/mihomo/common/lru"
@@ -13,6 +14,7 @@ type ResolverEnhancer struct {
 	fakeIPPool    *fakeip.Pool
 	fakeIPPool6   *fakeip.Pool
 	fakeIPSkipper *fakeip.Skipper
+	fakeIPTTL     int
 	mapping       *lru.LruCache[netip.Addr, string]
 	useHosts      bool
 }
@@ -31,11 +33,15 @@ func (h *ResolverEnhancer) IsExistFakeIP(ip netip.Addr) bool {
 	}
 
 	if pool := h.fakeIPPool; pool != nil {
-		return pool.Exist(ip)
+		if pool.Exist(ip) {
+			return true
+		}
 	}
 
 	if pool6 := h.fakeIPPool6; pool6 != nil {
-		return pool6.Exist(ip)
+		if pool6.Exist(ip) {
+			return true
+		}
 	}
 
 	return false
@@ -47,11 +53,15 @@ func (h *ResolverEnhancer) IsFakeIP(ip netip.Addr) bool {
 	}
 
 	if pool := h.fakeIPPool; pool != nil {
-		return pool.IPNet().Contains(ip) && ip != pool.Gateway() && ip != pool.Broadcast()
+		if pool.IPNet().Contains(ip) && ip != pool.Gateway() && ip != pool.Broadcast() {
+			return true
+		}
 	}
 
 	if pool6 := h.fakeIPPool6; pool6 != nil {
-		return pool6.IPNet().Contains(ip) && ip != pool6.Gateway() && ip != pool6.Broadcast()
+		if pool6.IPNet().Contains(ip) && ip != pool6.Gateway() && ip != pool6.Broadcast() {
+			return true
+		}
 	}
 
 	return false
@@ -63,11 +73,15 @@ func (h *ResolverEnhancer) IsFakeBroadcastIP(ip netip.Addr) bool {
 	}
 
 	if pool := h.fakeIPPool; pool != nil {
-		return pool.Broadcast() == ip
+		if pool.Broadcast() == ip {
+			return true
+		}
 	}
 
 	if pool6 := h.fakeIPPool6; pool6 != nil {
-		return pool6.Broadcast() == ip
+		if pool6.Broadcast() == ip {
+			return true
+		}
 	}
 
 	return false
@@ -102,11 +116,19 @@ func (h *ResolverEnhancer) InsertHostByIP(ip netip.Addr, host string) {
 }
 
 func (h *ResolverEnhancer) FlushFakeIP() error {
+	var errs []error
 	if pool := h.fakeIPPool; pool != nil {
-		return pool.FlushFakeIP()
+		if err := pool.FlushFakeIP(); err != nil {
+			errs = append(errs, err)
+		}
 	}
 	if pool6 := h.fakeIPPool6; pool6 != nil {
-		return pool6.FlushFakeIP()
+		if err := pool6.FlushFakeIP(); err != nil {
+			errs = append(errs, err)
+		}
+	}
+	if len(errs) > 0 {
+		return errors.Join(errs...)
 	}
 	return nil
 }
@@ -141,6 +163,7 @@ type EnhancerConfig struct {
 	FakeIPPool    *fakeip.Pool
 	FakeIPPool6   *fakeip.Pool
 	FakeIPSkipper *fakeip.Skipper
+	FakeIPTTL     int
 	UseHosts      bool
 }
 
@@ -156,6 +179,10 @@ func NewEnhancer(cfg EnhancerConfig) *ResolverEnhancer {
 			e.fakeIPPool6 = cfg.FakeIPPool6
 		}
 		e.fakeIPSkipper = cfg.FakeIPSkipper
+		e.fakeIPTTL = cfg.FakeIPTTL
+		if e.fakeIPTTL < 1 {
+			e.fakeIPTTL = 1
+		}
 		e.mapping = lru.New(lru.WithSize[netip.Addr, string](4096))
 	}
 
