@@ -5,8 +5,8 @@ import (
 	"encoding/binary"
 
 	"github.com/metacubex/mihomo/common/buf"
+	N "github.com/metacubex/mihomo/common/net"
 	"github.com/metacubex/mihomo/log"
-	N "github.com/metacubex/sing/common/network"
 
 	"github.com/gofrs/uuid/v5"
 	"github.com/metacubex/randv2"
@@ -20,7 +20,7 @@ const (
 	commandPaddingDirect   byte = 0x02
 )
 
-func ApplyPadding(buffer *buf.Buffer, command byte, userUUID *uuid.UUID, paddingTLS bool) {
+func ApplyPadding(buffer *buf.Buffer, command byte, userUUID *[]byte, paddingTLS bool) {
 	contentLen := int32(buffer.Len())
 	var paddingLen int32
 	if contentLen < 900 {
@@ -35,25 +35,33 @@ func ApplyPadding(buffer *buf.Buffer, command byte, userUUID *uuid.UUID, padding
 	binary.BigEndian.PutUint16(buffer.ExtendHeader(2), uint16(paddingLen))
 	binary.BigEndian.PutUint16(buffer.ExtendHeader(2), uint16(contentLen))
 	buffer.ExtendHeader(1)[0] = command
-	if userUUID != nil {
-		copy(buffer.ExtendHeader(uuid.Size), userUUID.Bytes())
+	if userUUID != nil && *userUUID != nil {
+		copy(buffer.ExtendHeader(uuid.Size), *userUUID)
+		*userUUID = nil
 	}
 
 	buffer.Extend(int(paddingLen))
 	log.Debugln("XTLS Vision write padding: command=%d, payloadLen=%d, paddingLen=%d", command, contentLen, paddingLen)
 }
 
+const xrayBufSize = 8192
+
 func (vc *Conn) ReshapeBuffer(buffer *buf.Buffer) []*buf.Buffer {
-	const xrayBufSize = 8192
-	if buffer.Len() <= xrayBufSize-PaddingHeaderLen {
+	const bufferLimit = xrayBufSize - PaddingHeaderLen
+	if buffer.Len() < bufferLimit {
 		return []*buf.Buffer{buffer}
 	}
-	cutAt := bytes.LastIndex(buffer.Bytes(), tlsApplicationDataStart)
-	if cutAt == -1 {
-		cutAt = xrayBufSize / 2
+	options := N.NewReadWaitOptions(nil, vc)
+	var buffers []*buf.Buffer
+	for buffer.Len() >= bufferLimit {
+		cutAt := bytes.LastIndex(buffer.Bytes(), tlsApplicationDataStart)
+		if cutAt < 21 || cutAt > bufferLimit {
+			cutAt = xrayBufSize / 2
+		}
+		buffer2 := options.NewBuffer() // ensure the new buffer can send used in vc.WriteBuffer
+		buf.Must(buf.Error(buffer2.ReadFullFrom(buffer, cutAt)))
+		buffers = append(buffers, buffer2)
 	}
-	buffer2 := N.NewReadWaitOptions(nil, vc).NewBuffer() // ensure the new buffer can send used in vc.WriteBuffer
-	buffer2.Write(buffer.From(cutAt))
-	buffer.Truncate(cutAt)
-	return []*buf.Buffer{buffer, buffer2}
+	buffers = append(buffers, buffer)
+	return buffers
 }
