@@ -70,7 +70,9 @@ func (d *DNSDialer) DialContext(ctx context.Context, network, addr string) (net.
 		} else {
 			var ok bool
 			proxyAdapter, ok = Proxies()[proxyName]
-			if !ok {
+			if ok {
+				metadata.SpecialProxy = proxyName // just for log
+			} else {
 				opts = append(opts, dialer.WithInterface(proxyName))
 			}
 		}
@@ -158,7 +160,9 @@ func (d *DNSDialer) ListenPacket(ctx context.Context, network, addr string) (net
 		} else {
 			var ok bool
 			proxyAdapter, ok = Proxies()[proxyName]
-			if !ok {
+			if ok {
+				metadata.SpecialProxy = proxyName // just for log
+			} else {
 				opts = append(opts, dialer.WithInterface(proxyName))
 			}
 		}
